A dataset containing the adult model interaction factors for the risk adjustment model. Certain HCCs are considered "high risk" HCCs, and when one of these high risk HCCs interacts with certain other HCCs, an additional interaction term is added to the risk score.
adult_interactionAn object of class tbl_df (inherits from tbl, data.frame) with
2 rows and 7 columns
Interaction group (M/H)
Whether or not the category is used in the RA model
HCC grouping risk score for each metal level
Other factors:
adult_demo,
adult_enroll_dur,
adult_group,
adult_hcc,
adult_rxc_hcc_inter,
adult_rxc,
child_demo,
child_group,
child_hcc,
infant_demo,
infant_mat_sev
Other HCC tables:
adult_group,
adult_hcc,
adult_rxc_hcc_inter,
cc_hier,
child_group,
child_hcc,
cpt_hcpcs,
icd_cc