A dataset containing the adult model RXC/HCC interaction factors for the risk adjustment model. Some HCCs have built-in risk for the associated drugs, so if a member has both the diagnosis and the drug, their risk is overstated. Other drugs combined with conditions indicate a greater severity than either the drug or the condition alone, so risk is understated. The RXC/HCC interaction factors make these adjustments.
adult_rxc_hcc_interAn object of class tbl_df (inherits from tbl, data.frame) with
32 rows and 8 columns
Whether or not the category is used in the RA model
HCC grouping risk score for each metal level
RXC label for risk scores (Includes leading zeroes)
HCC label for risk scores (Includes leading zeroes)
Other factors:
adult_demo,
adult_enroll_dur,
adult_group,
adult_hcc,
adult_interaction,
adult_rxc,
child_demo,
child_group,
child_hcc,
infant_demo,
infant_mat_sev
Other HCC tables:
adult_group,
adult_hcc,
adult_interaction,
cc_hier,
child_group,
child_hcc,
cpt_hcpcs,
icd_cc