A dataset containing the child model demographic factors for the risk adjustment model. Demographics vary by age (groupings) and sex.
child_demoAn object of class tbl_df (inherits from tbl, data.frame) with
8 rows and 9 columns
Whether or not the category is used in the RA model
Demographic risk score for each metal level
Male/Female demographic category
Maximum and minimum age for each risk score
Other factors:
adult_demo,
adult_enroll_dur,
adult_group,
adult_hcc,
adult_interaction,
adult_rxc_hcc_inter,
adult_rxc,
child_group,
child_hcc,
infant_demo,
infant_mat_sev