Learn R Programming

edgedata (version 0.2.0)

hcpcs_rxc: HCPCS to Rx Condition Crosswalk - Table 10b

Description

A dataset containing the HCPCS to Rx condition mappings.

Usage

hcpcs_rxc

Arguments

Format

An object of class tbl_df (inherits from tbl, data.frame) with 43 rows and 3 columns

rxc

Rx condition number without leading zeroes

desc

Rx condition description

ndc

HCPCS code that maps to rxc

Details

HCPCS codes create a system for identifying drugs given in a medical setting. But since there are so many drugs, and they very specific, the HHS-HCC model groups similar drugs into broader Rx condition categories.

See Also

Other crosswalks: icd_cc, ndc_rxc

Other RXC tables: adult_rxc_hcc_inter, adult_rxc, ndc_rxc, rxc_hier