A dataset containing the NDC to Rx condition mappings.
ndc_rxcAn object of class tbl_df (inherits from tbl, data.frame) with
12323 rows and 3 columns
Rx condition number without leading zeroes
Rx condition description
NDC that maps to rxc
The NDC system is a unique drug identifier system. But since there are so many drugs, and they very specific, the HHS-HCC model groups similar drugs into broader Rx condition categories.
Other crosswalks:
hcpcs_rxc,
icd_cc
Other RXC tables:
adult_rxc_hcc_inter,
adult_rxc,
hcpcs_rxc,
rxc_hier