A dataset used to apply the risk adjustment Rx condition category hierarchies. The HHS risk model uses hierarchical condition categories. This means that when an individual has e.g. RXC 6 (Insulin), they do not also get the risk score for RXC 7 (Anti-Diabetic Agents, Except Insulin...).
rxc_hierAn object of class tbl_df (inherits from tbl, data.frame) with
1 rows and 3 columns
Rx condition code without leading zeroes
Rx condition code description
Rx condition code that falls below rxc on the hierarchy
No leading zeroes
Other RXC tables:
adult_rxc_hcc_inter,
adult_rxc,
hcpcs_rxc,
ndc_rxc