A dataset containing the HCPCS to Rx condition mappings.
hcpcs_rxcAn object of class tbl_df (inherits from tbl, data.frame) with
43 rows and 3 columns
Rx condition number without leading zeroes
Rx condition description
HCPCS code that maps to rxc
HCPCS codes create a system for identifying drugs given in a medical setting. But since there are so many drugs, and they very specific, the HHS-HCC model groups similar drugs into broader Rx condition categories.
Other crosswalks:
icd_cc,
ndc_rxc
Other RXC tables:
adult_rxc_hcc_inter,
adult_rxc,
ndc_rxc,
rxc_hier